/* FILE: osivs.h
 * 
 * Copyright (c) 2003-2005 James A. Strother
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef __OSIVS_H__
#define __OSIVS_H__

#include <stdint.h>

/* define type sizes */
#define OSIVS_IOINT_BYTES 4
#define OSIVS_IOREAL_BYTES 4

#define OSIVS_INT_BYTES 4
#define OSIVS_REAL_BYTES 8

/* find type for osivs_ioint_t */
#if OSIVS_IOINT_BYTES == 1 
typedef int8_t osivs_ioint_t;
#elif OSIVS_IOINT_BYTES == 2
typedef int16_t osivs_ioint_t;
#elif OSIVS_IOINT_BYTES == 4
typedef int32_t osivs_ioint_t;   
#elif OSIVS_IOINT_BYTES == 8   
typedef int64_t osivs_ioint_t;
#else
# error "no type for osivs_ioint_t"
#endif

/* find type for osivs_ioreal_t */
#if OSIVS_IOREAL_BYTES == 4 
typedef float osivs_ioreal_t;
#elif OSIVS_IOREAL_BYTES == 8   
typedef double osivs_ioreal_t;
#else
# error "no type for osivs_ioreal_t"
#endif

/* find type for osivs_int */
#if OSIVS_INT_BYTES == 1
typedef int8_t osivs_int;  
#elif OSIVS_INT_BYTES == 2  
typedef int16_t osivs_int; 
#elif OSIVS_INT_BYTES == 4  
typedef int32_t osivs_int;
#elif OSIVS_INT_BYTES == 8
typedef int64_t osivs_int;
#else
# error "no type for osivs_int"
#endif

/* find type for osivs_real */
#if OSIVS_REAL_BYTES == 4  
typedef float osivs_real;  
#elif OSIVS_REAL_BYTES == 8
typedef double osivs_real;
#else
# error "no type for osivs_real"
#endif

/* define error codes */
enum {
   OSIVS_EOKAY,    OSIVS_EMEM,
   OSIVS_ETRIES,   OSIVS_ETREE,
   OSIVS_EFFMT,    OSIVS_EFORK,
   OSIVS_EFILT,    OSIVS_EFLESS,
   OSIVS_EFMORE,   OSIVS_ETEMP,
   OSIVS_EIBITS,   OSIVS_EOUTF,
   OSIVS_EXSIZE,   OSIVS_EYSIZE,
   OSIVS_EZSIZE,   OSIVS_EXEDGE,
   OSIVS_EYEDGE,   OSIVS_EZEDGE,
   OSIVS_ESPACE,   OSIVS_EDENS,
   OSIVS_ESMIN,    OSIVS_ESMAX,
   OSIVS_ESCMP,    OSIVS_ESAVG,
   OSIVS_ESDEV,    OSIVS_ESBND,
   OSIVS_EBMIN,    OSIVS_EBMAX,
   OSIVS_EBCMP,    OSIVS_EBAVG,
   OSIVS_EBDEV,    OSIVS_EBBND
};

typedef struct
{
  char*          out_fnam0;
  char*          out_fnam1;
  char*          filt_src;
  char*          backg_src;
  osivs_ioint_t    rand_seed;
  osivs_ioint_t    image_xsize;
  osivs_ioint_t    image_ysize;
  osivs_ioreal_t   image_zsize;
  osivs_ioint_t    image_depth;
  osivs_ioreal_t   image_xedge;
  osivs_ioreal_t   image_yedge;
  osivs_ioreal_t   image_zedge;
  osivs_ioreal_t   dot_space;
  osivs_ioreal_t   dot_density;
  osivs_ioreal_t   dot_size_min;
  osivs_ioreal_t   dot_size_max;
  osivs_ioreal_t   dot_size_avg;
  osivs_ioreal_t   dot_size_dev;
  osivs_ioreal_t   dot_brite_min;
  osivs_ioreal_t   dot_brite_max;
  osivs_ioreal_t   dot_brite_avg;
  osivs_ioreal_t   dot_brite_dev;
} osivs_args_t;

/* error.c */
const char* osivs_strerr(osivs_int);

/* osivs.c */
osivs_int osivs_run(osivs_args_t* a);

#endif
