/* FILE: error.c
 *
 * Copyright (c) 2003 James A. Strother
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include "osivx-devel.h"


/*********************************************************
 * The following function returns a string that describes
 * the error code which it is passed.  It returns NULL if
 * the error code is not recognized.
 *********************************************************/
const char*
osivx_strerr(
   osivx_int e)
{
   const char* s;

   switch (e)
   {
   case OSIVX_EMEM:
      s = "out of memory";
      break;
   case OSIVX_EALG:
      s = "unrecognized correlation algorithm";
      break;
   case OSIVX_EPREPROC:
      s = "unrecognized preprocessing algorithm";
      break;
   case OSIVX_EINTERP:
      s = "unrecognized interpolation algorithm";
      break;
   case OSIVX_EIMAGEXSIZE:
      s = "horizontal image size must be greater than zero";
      break;
   case OSIVX_EIMAGEYSIZE:
      s = "vertical image size must be greater than zero";
      break;
   case OSIVX_EGRIDXSTART:
      s = "x grid start location must be positive";
      break;
   case OSIVX_EGRIDYSTART:
      s = "y grid start location must be positive";
      break;
   case OSIVX_EGRIDXOFFSET:
      s = "improper x grid offset";
      break;
   case OSIVX_EGRIDYOFFSET:
      s = "improper y grid offset";
      break;
   case OSIVX_EGRIDXSPACING:
      s = "x grid spacing must be greater than zero";
      break;
   case OSIVX_EGRIDYSPACING:
      s = "y grid spacing must be greater than zero";
      break;
   case OSIVX_EGRIDXSIZE:
      s = "x grid size must be greater than zero";
      break;
   case OSIVX_EGRIDYSIZE:
      s = "y grid size must be greater than zero";
      break;
   case OSIVX_EWINDXSIZE:
      s = "horizontal window size must be greater than zero";
      break;
   case OSIVX_EWINDYSIZE:
      s = "vertical window size must be greater than zero";
      break;
   case OSIVX_EWINDXSUPER:
      s = "horizontal super window size less than window size";
      break;
   case OSIVX_EWINDYSUPER:
      s = "vertical super window size less than window size";
      break;
   case OSIVX_EDISPXMAX:
      s = "maximum x displacement must be greater than zero";
      break;
   case OSIVX_EDISPYMAX:
      s = "maximum y displacement must be greater than zero";
      break;
   case OSIVX_EMOVIESTART:
      s = "movie start number must be positive";
      break;
   case OSIVX_EMOVIEFINISH:
      s = "movie finish number less than movie start";
      break;
   case OSIVX_EMOVIESKIP:
      s = "movie skipping number must be greater than zero";
      break;
   case OSIVX_EMOVIESET:
      s = "movie set number must be positive";
      break;
   case OSIVX_ENUMITER:
      s = "number of iterations must be greater than zero";
      break;
   case OSIVX_ENUMTHRD:
      s = "number of threads must be greater than zero";
      break;
   case OSIVX_EMOVAFILE:
      s = "unable to open first movie file";
      break;
   case OSIVX_EMOVBFILE:
      s = "unable to open second movie file";
      break;
   case OSIVX_EVECFILE:
      s = "unable to open output file";
      break;
   case OSIVX_EWRITEMAP:
      s = "write-map switch is not allowed with these options";
      break;
   case OSIVX_EXGRID:
      s = "x grid exceeds image dimensions";
      break;
   case OSIVX_EYGRID:
      s = "y grid exceeds image dimensions";
      break;
   case OSIVX_EMOVDIR:
      s = "movie lacks requested frame";
      break;
   case OSIVX_EMOVRAW:
      s = "RAW image is unreadable";
      break;
   case OSIVX_EMOVTIFF:
      s = "TIFF image is unreadable";
      break;
   case OSIVX_EMOVTYPE:
      s = "unrecognized movie type";
      break;
   case OSIVX_EMOVXSIZE:
      s = "movie has conflicting horizontal image size";
      break;
   case OSIVX_EMOVYSIZE:
      s = "movie has conflicting vertical image size";
      break;
   case OSIVX_EFILEMODE:
      s = "vectors file opened with improper mode";
      break;
   case OSIVX_EFILEPOS:
      s = "vectors file could not be positioned";
      break;
   case OSIVX_EFILEREAD:
      s = "vectors file is unreadable";
      break;
   case OSIVX_EFILEWRITE:
      s = "vectors file is unwriteable";
      break;
   case OSIVX_EDISPINT:
      s = "maximum displacement exceeds compiled limit";
      break;
   case OSIVX_EWINDINT:
      s = "maximum window size exceeds compiled limit";
      break;
   case OSIVX_EFRAMEINT:
      s = "maximum frame size exceeds compiled limit";
      break;
   case OSIVX_EMOVIEINT:
      s = "maximum movie length exceeds compiled limit";
      break;
   case OSIVX_EIMAGEINT:
      s = "number of image bits differs from compiled value";
      break;
   case OSIVX_EFFTPLAN:
      s = "fftw planning session failed";
      break;
   case OSIVX_ETHREAD:
      s = "failed to spawn usable thread";
      break;
   case OSIVX_EMOVXFILE:
      s = "unable to perform movie operations";
      break;
   case OSIVX_EWTHREADS:
      s = "algorithm requires threaded compilation";
      break;
   case OSIVX_EMOVSETEQ:
      s = "algorithm requires movie set and skip be equal";
      break;
   case OSIVX_EGRID:
      s = "window grid engine generated error";
      break;
   case OSIVX_EDISPXITER:
      s = "maximum x iterative displacement must be positive";
      break;
   case OSIVX_EDISPYITER:
      s = "maximum y iterative displacement must be positive";
      break;
   default: return NULL;
   }

   return s;
}

